##  Selecting Fact Sheets by Filter
The Select by Filter feature allows you to easily select fact sheet shapes on the canvas based on specific criteria. This can be done using the Select button in the toolbar or by right-clicking on the canvas and choosing the “Select by Filter” option from the menu. Once a filter is applied, a filter icon will appear in the bottom-right corner of the filtered shape.
Using the Select button:
  1. Click the Select button in the toolbar.
  2. A modal will appear where you can apply filters to select your desired fact sheets.


Using the right-click menu:
  1. Right-click on the canvas.
  2. Choose the Drill-Down by Filter or Roll-Up by Filter option.
  3. A modal will appear where you can apply filters to select your desired fact sheets.


Filtering in Data Flow
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio4f15a6b5902d456c9ec5da588bc18dc2_LowRes.gif)
